ExplicitCheckpointKeeper
========================

.. currentmodule:: pykeen.checkpoints

.. autoclass:: ExplicitCheckpointKeeper
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ExplicitCheckpointKeeper.__call__

   .. rubric:: Methods Documentation

   .. automethod:: __call__
